@@ -1,4 +1,4 @@
-__all__ = ["load", "visit"]
+__all__ = ["load", "visit", "rust_tokenizer_or_raise", "ExtensionUnavailable"]
 
 try:
     from .json_stream_rs_tokenizer import RustTokenizer
@@ -7,6 +7,13 @@ try:
 except ImportError:
     pass
 
+try:
+    from .json_stream_rs_tokenizer import supports_bigint
+
+    __all__.append("supports_bigint")
+except ImportError:
+    pass
+
 
 class ExtensionUnavailable(Exception):
     pass
